==> curia-4.2.0b7.tar.gz: curia-4.2.0b7/src/curia/api/docs/ModelPopulationResponseDto.md <==
# ModelPopulationResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cohorts** | [**ModelPopulationJoinedCohortDefinitionResponseDto**](ModelPopulationJoinedCohortDefinitionResponseDto.md) |  | [optional] 
**outcome** | [**ModelPopulationJoinedOutcomeDefinitionResponseDto**](ModelPopulationJoinedOutcomeDefinitionResponseDto.md) |  | [optional] 
**intervention** | [**ModelPopulationJoinedInterventionDefinitionResponseDto**](ModelPopulationJoinedInterventionDefinitionResponseDto.md) |  | [optional] 
**features** | [**ModelPopulationJoinedFeatureResponseDto**](ModelPopulationJoinedFeatureResponseDto.md) |  | [optional] 
**cohort_results** | [**ModelPopulationJoinedCohortResultsResponseDto**](ModelPopulationJoinedCohortResultsResponseDto.md) |  | [optional] 
**data_query** | [**ModelPopulationJoinedDataQueryResponseDto**](ModelPopulationJoinedDataQueryResponseDto.md) |  | [optional] 
**model_jobs** | [**ModelPopulationJoinedModelJobResponseDto**](ModelPopulationJoinedModelJobResponseDto.md) |  | [optional] 
**outcome_distribution_histogram_query** | [**ModelPopulationJoinedDataQueryResponseDto**](ModelPopulationJoinedDataQueryResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**query_count_status** | **str** |  | [optional] 
**query_count_error** | **str** |  | [optional] 
**query_list_status** | **str** |  | [optional] 
**query_list_error** | **str** |  | [optional] 
**query_all_status** | **str** |  | [optional] 
**query_all_error** | **str** |  | [optional] 
**query_count_started_at** | **datetime** |  | [optional] 
**query_count_ended_at** | **datetime** |  | [optional] 
**query_list_started_at** | **datetime** |  | [optional] 
**query_list_ended_at** | **datetime** |  | [optional] 
**query_all_started_at** | **datetime** |  | [optional] 
**query_all_ended_at** | **datetime** |  | [optional] 
**organization_id** | **str** |  | [optional] 
**population_id** | **str** |  | [optional] 
**data_query_id** | **str** |  | [optional] 
**outcome_distribution_histogram_query_id** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**created_by** | **str** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> curia-4.6.0.tar.gz: curia-4.6.0/src/curia/api/docs/ModelPopulationResponseDto.md <==
# ModelPopulationResponseDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cohorts** | [**list[ModelPopulationJoinedCohortDefinitionResponseDto]**](ModelPopulationJoinedCohortDefinitionResponseDto.md) |  | [optional] 
**outcome** | [**ModelPopulationJoinedOutcomeDefinitionResponseDto**](ModelPopulationJoinedOutcomeDefinitionResponseDto.md) |  | [optional] 
**intervention** | [**ModelPopulationJoinedInterventionDefinitionResponseDto**](ModelPopulationJoinedInterventionDefinitionResponseDto.md) |  | [optional] 
**features** | [**list[ModelPopulationJoinedFeatureResponseDto]**](ModelPopulationJoinedFeatureResponseDto.md) |  | [optional] 
**cohort_results** | [**list[ModelPopulationJoinedCohortResultsResponseDto]**](ModelPopulationJoinedCohortResultsResponseDto.md) |  | [optional] 
**data_query** | [**ModelPopulationJoinedDataQueryResponseDto**](ModelPopulationJoinedDataQueryResponseDto.md) |  | [optional] 
**model_jobs** | [**list[ModelPopulationJoinedModelJobResponseDto]**](ModelPopulationJoinedModelJobResponseDto.md) |  | [optional] 
**outcome_distribution_histogram_query** | [**ModelPopulationJoinedDataQueryResponseDto**](ModelPopulationJoinedDataQueryResponseDto.md) |  | [optional] 
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**query_count_status** | **str** |  | [optional] 
**query_count_error** | **str** |  | [optional] 
**query_list_status** | **str** |  | [optional] 
**query_list_error** | **str** |  | [optional] 
**query_all_status** | **str** |  | [optional] 
**query_all_error** | **str** |  | [optional] 
**query_count_started_at** | **datetime** |  | [optional] 
**query_count_ended_at** | **datetime** |  | [optional] 
**query_list_started_at** | **datetime** |  | [optional] 
**query_list_ended_at** | **datetime** |  | [optional] 
**query_all_started_at** | **datetime** |  | [optional] 
**query_all_ended_at** | **datetime** |  | [optional] 
**organization_id** | **str** |  | [optional] 
**population_id** | **str** |  | [optional] 
**data_query_id** | **str** |  | [optional] 
**outcome_distribution_histogram_query_id** | **str** |  | [optional] 
**created_at** | **datetime** |  | [optional] 
**created_by** | **str** |  | [optional] 
**updated_at** | **datetime** |  | [optional] 
**archived_at** | **datetime** |  | [optional] 
**last_updated_by** | **str** |  | [optional] 
**version** | **float** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
